from setuptools import setup, find_packages

setup(
    name="Hotel_Py_package",  # Nombre único en PyPI
    version='0.0.1',    # Versión inicial
    packages=find_packages(),  # Encuentra automáticamente submódulos y subpaquetes
    description='Simple application for task management using Python, based on the example of a hotel booking manager.',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    author='Manuel Pulido',
    author_email='moepulido@ymail.com',
    url='https://github.com/Moepulido/hotel_py',  # URL del repositorio
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.6',
)